@@ -3,8 +3,13 @@
 from droughty.droughty_lookml.lookml_module import output
 from droughty.droughty_lookml.lookml_explore_module import explore_output
 from droughty.droughty_lookml.lookml_measure_module import measure_output
+from droughty.droughty_lookml.lookml_pop_module import pop_output
+from droughty.droughty_lookml.lookml_pop_module_snowflake import pop_output_snowflake
 
-from droughty.droughty_core.config import ExploresVariables
+from droughty.droughty_core.config import (
+    ExploresVariables,
+    ProjectVariables
+)
 
 dimensional_inference_status = ExploresVariables.explore_tables
 
@@ -50,6 +55,26 @@ def lookml_measures():
 
         print("lookml measure layer generated")
 
+def lookml_pop():
+
+    if ExploresVariables.lookml_pop != None:
+
+        print("Generating base parameter layer")
+
+        try:
+
+            if ProjectVariables.warehouse == 'big_query':
+
+                return pop_output()
+
+            elif ProjectVariables.warehouse == 'snowflake':
+
+                return pop_output_snowflake()
+
+        finally:
+
+            print("lookml base parameter layer generated")
+
 
 #def full_refresh():
 #
